import sys, re

# TODO: cmd line help / click
# asciinema

def pinmyreqs():
	# pip freeze | pinmyreqs requirements.txt
	# TODO: pin the unpinned
	freezed = {}
	for line in sys.stdin:
		line = line.strip()
		if line and not line.startswith('-e '):
			m = re.match('([\w\d\-\_\.]+)==([\w\d\.]+)', line)
			if m:
				pkg, version = m.groups()
				freezed[pkg] = version
			else:
				print('Invalid line:', line, file=sys.stderr)

	for line in open(sys.argv[1]):
		line = line.strip()
		m = re.match('([\w\d\-\_\.]+)==([\w\d\.]+)', line)
		if m:
			pkg, version = m.group(1), m.group(2)
			if pkg in freezed:
				print('%s==%s' % (pkg, freezed[pkg]))
			else:
				print(line)
		else:
			print(line)


def unpinmyreqs():
	for line in open(sys.argv[1]):
		line = line.strip()
		m = re.match('([\w\d\-\_\.]+)==([\w\d\.]+)', line)
		if m:
			print(m.group(1))
		else:
			print(line)


# -*- coding: utf-8 -*-
import sys
from setuptools import setup

setup(
    name='pinmyreqs',
    version='0.1',
    description='Pin your requirement.txt without adding new dependencies',
    long_description=open('README.rst').read(),
    url='http://github.com/mdamien/pinmyreqs',
    author='Damien MARIÉ',
    author_email='damien@dam.io',
    license='MIT',
    classifiers=[
        'Intended Audience :: Developers',
        'Natural Language :: English',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
    ],
    entry_points = {
        'console_scripts': [
            'pinmyreqs=pinmyreqs:pinmyreqs',
            'unpinmyreqs=pinmyreqs:unpinmyreqs',
        ],
    },
    packages=['pinmyreqs'],
    zip_safe=False
)
